#
# Copyright 2011 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#

import optparse
from albatross.cmdline.common import *

def generate_page_file(input_filename, output_filename, replace):
    if not os.path.exists(input_filename):
        raise Error('missing skeleton file %s' % input_filename)
    if os.path.exists(output_filename):
        raise Error('file %s already exists' % output_filename)
    f = open(input_filename)
    try:
        data = f.read()
    finally:
        f.close()
    for key, value in replace.items():
        data = data.replace(key, value)
    f = open(output_filename, 'w')
    try:
        f.write(data)
    finally:
        f.close()


def cmd_create_page(name):
    skeldir = os.path.join(get_skeleton_dir(), 'page')
    parts = split_posix_path(name)
    curdir = os.path.abspath(os.curdir)
    dest = os.path.join(curdir, 'pages', *parts[0:-1])
    name = parts[-1]
    for i, part in enumerate(parts[0:-1]):
        part_path = os.path.join(curdir, 'pages', *parts[:i+1])
        init_file = os.path.join(part_path, '__init__.py')
        if not os.path.isdir(part_path):
            os.mkdir(part_path)
        if not os.path.isfile(init_file):
            open(init_file, 'w').write('')
    if len(parts) > 1:
        path = posixpath.join(*parts[0:-1])
        path = posixpath.join(path, name)
    else:
        path = name
    replace = {
        '@NAME@': name,
        '@PATH@': path,
    }
    generate_page_file(os.path.join(skeldir, 'page.py'),
                       os.path.join(dest, '%s.py' % name),
                       replace)
    generate_page_file(os.path.join(skeldir, 'page.html'),
                       os.path.join(dest, '%s.html' % name),
                       replace)


usage = '''%prog add-page <name>
        add a new page to an Albatross application'''

def main(args):
    optp = optparse.OptionParser(usage=usage)
    options, args = optp.parse_args(args)
    if len(args) != 1:
        optp.error('specify a name for your new page')
    cmd_create_page(args[0])
