#
# Copyright 2011 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#

import os
import optparse
import shutil
import random
import string
from ConfigParser import RawConfigParser

from albatross.cmdline.common import *

def cmd_create_app(name):
    if os.path.exists(name):
        raise Error('%s already exists' % name)
    skeldir = os.path.join(get_skeleton_dir(), 'app')
    for root, dirs, files in os.walk(skeldir):
        # Prevent walk generator from stepping into subversion dirs.
        if '.svn' in dirs:
            dirs.remove('.svn')
        dest = os.path.join(name, root[len(skeldir)+len(os.sep):])
        os.makedirs(dest)
        for fn in files:
            if fn.endswith('.pyc') or fn.endswith('~'):
                continue
            shutil.copy(os.path.join(root, fn),
                        os.path.join(dest, fn))
    os.mkdir(os.path.join(name, 'session'))
    cfg = RawConfigParser()
    cfg.add_section('application')
    cfg.set('application', 'name', name)
    cfg.set('application', 'debug', 'True')
    cfg.set('application', 'page_model', 'random')
    cfg.set('application', 'context_model', 'session-file')
    cfg.set('application', 'session_path', 'session')
    cfg.set('application', 'static_path', '/%s-static' % name)
    cfg.set('application', 'start_page', 'main')
    secret = ''.join(random.sample(string.letters + string.digits, 20))
    cfg.set('application', 'secret', secret)
    cfg.add_section('logging')
    cfg.set('logging', 'filename', 'app.log')
    cfg.set('logging', 'level', 'DEBUG')
    cfg.set('logging', 'format', '%(asctime)s %(name)s[%(process)d]: %(levelname)s %(message)s')
    cfg.set('logging', 'datefmt', '%Y-%m-%d %H:%M:%S')
    cfg.write(open(os.path.join(name, 'app.ini'), 'w'))


usage = '''%prog create <name>
        creates a new Albatross application called <name>.'''

def main(args):
    optp = optparse.OptionParser(usage=usage)
    options, args = optp.parse_args(args)
    if len(args) != 1:
        optp('specify a name for your new application')
    cmd_create_app(args[0])

