#
# Copyright 2011 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#

import sys
import os
import optparse
import socket

from albatross import httpdapp
from albatross.cmdline.common import *

#TODO
# IPv6 support?
#>>> s=socket.socket(socket.AF_INET6)
#>>> s.bind(('::1', 9000))

usage = '''%prog serve [module.app_object]
        Start an albatross application in stand-alone development mode.
        An optional module containing an Application object can be specified.'''

def main(args):
    optp = optparse.OptionParser(usage=usage)
    optp.add_option('-p', '--port', type='int', default=8000,
                    help='listen on PORT (default: 8000)')
    optp.add_option('-q', '--quiet', action='store_true',
                    help='operate quietly')
    optp.add_option('-s', '--static', action='append', 
                    metavar='URL_PREFIX:FILE_PATH',
                    help='Specify additional static resource paths')
    options, args = optp.parse_args(args)

    static_resources = []
    if options.static:
        for prefixpath in options.static:
            prefix, path = prefixpath.split(':', 1)
            static_resources.append((prefix, path))
    if args:
        sys.path.append(os.getcwd())
        appname = args.pop(0)
        try:
            module_name, module_app_name = appname.split('.')
        except ValueError:
            optp.error('Application must be specified as module.app_object, '
                       'not %r' % appname)
        # Load the application's module and get application instance.
        module = __import__(module_name)
        app = getattr(module, module_app_name)
        # For compatibility with the old al-httpd, we also accept static
        # mappings via args pairs
        while args:
            try:
                uri, fs = args[:2]
            except ValueError:
                optp.error('static_url and file_path must be paired')
            args = args[2:]
            static_resources.append((uri, fs))
    else:
        app = load_app()
        appname = app.cfg.name
        static_resources.append(('%s' % app.cfg.static_path, 'static'))

    if not options.quiet:
        print 'Starting web server for "%s" on port %s' %\
            (appname, options.port)
        if sys.platform == 'win32':
            print 'Stop the server with Ctrl-Break'
        else:
            # import termios
            # termios.tcgetattr(0)[6][termios.VINTR]
            print 'Stop the server with Ctrl-C'

    app._Application__base_url = '/'
    try:
        httpd = httpdapp.HTTPServer(app, options.port, static_resources)
        if not options.quiet:
            print 'http://%s:%s/' % (socket.getfqdn(), options.port)
        httpd.serve_forever()
    except KeyboardInterrupt:
        sys.exit(0)
    except socket.error, e:
        raise Error(e[1])
