#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#

import urlparse

from albatross.template import Template
from albatross.context import _caller_globals
from albatross.app import PageModuleMixin
from albatross.common import *

class RandomPageModuleMixin(PageModuleMixin):

    def load_page(self, ctx):
        # Get page name from request URI
        uri = ctx.request.get_uri()
        page = self.get_page_from_uri(ctx, uri)
        if not page:
            ctx.redirect(self.start_page())

        # Try to load the page module
        self.__page_found = 1
        try:
            self.load_page_module(ctx, page)
        except PageNotFound, e:
            ctx.locals.page_name = page
            self.__page_found = 0
        if self.__page_found:
            self.page_enter(ctx)

    def get_page_from_uri(self, ctx, uri):
        try:
            base_path = urlparse.urlparse(self.base_url())[2]
            uri_path = urlparse.urlparse(uri)[2]
            # Fixup base_path to end with a '/' so that it can be used as
            # a root path.
            if not base_path.endswith('/'):
                base_path =  base_path + '/'
            return uri_path.split(base_path, 1)[1]
        except IndexError:
            return None

    def load_badurl_template(self, ctx):
        try:
            return self.load_template('page_not_found.html')
        except TemplateLoadError:
            return Template(ctx, '<internal>',
'''<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
<html>
 <head>
  <title>404 Not Found</title>
 </head>
 <body>
  <h1>Oops!</h1>
   URL <al-value expr="page_name"> was not found on this server.<p>
 </body>
</html>
''')

    def page_enter(self, ctx):
        if self.__page_found:
            return PageModuleMixin.page_enter(self, ctx, ())
        return None

    def process_request(self, ctx):
        if self.__page_found:
            return PageModuleMixin.process_request(self, ctx)
        return None

    def display_response(self, ctx):
        if self.__page_found:
            PageModuleMixin.display_response(self, ctx)
        else:
            # Display error page - no page module so use the mainline
            # globals
            templ = self.load_badurl_template(ctx)
            ctx.set_globals(_caller_globals('run'))
            templ.to_html(ctx)
