import os


class PageNode:

    def __init__(self, ctx, name, path='pages'):
        self.name = name
        self.path = path
        self.isdir = os.path.isdir(path)
        if self.isdir:
            self.link = None
            self.load_children(ctx)
        else:
            parts = self.splitpath(os.path.dirname(path))
            parts.append(name)
            self.link = '/'.join(parts)

    def splitpath(self, path):
        parts = []
        path, part = os.path.split(path)
        while path:
            parts.append(part)
            path, part = os.path.split(path)
        parts.reverse()
        return parts

    def load_children(self, ctx):
        names = os.listdir(self.path)
        names.sort()
        self.children = []
        for name in names:
            if name in ('.', '..'):
                continue
            if os.path.isdir(os.path.join(self.path, name)):
                self.children.append(PageNode(ctx, name,
                                              os.path.join(self.path, name)))
            else:
                n, e = os.path.splitext(name)
                if e == '.py' and ('%s.html' % n) in names:
                    self.children.append(
                        PageNode(ctx, n, os.path.join(self.path, name)))


def page_display(ctx):
    ctx.locals.sesid = None
    if hasattr(ctx, 'sesid'):
        ctx.locals.sesid = ctx.sesid()
    ctx.locals.tree = PageNode(ctx, 'pages')
    ctx.run_template('main.html')
