# -*- coding: utf-8 -*-
import os
from util.db import Database, Row, ORDER_ASC


CONTACT_DB = 'contact.db'
contact_db_sql = '''CREATE TABLE contact(
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    firstname TEXT,
    lastname TEXT,
    address TEXT,
    city TEXT,
    postcode TEXT,
    email TEXT,
    home_phone TEXT,
    mobile_phone TEXT,
    office_phone TEXT);'''


class Contact(Row):

    table = 'contact'
    delete_contact = False


initial_contacts = [Contact(lastname=lastname,
                            firstname=firstname)
                    for firstname, lastname in (
        ('Ben', 'Affleck'),
        ('Shia', 'LaBeouf'),
        ('Enrique', 'Iglesias'),
        ('Colin', 'Farrell'),
        ('Nick', 'Lachey'),
        ('Johnny', 'Knoxville'),
        ('Jude', 'Law'),
        ('Daniel', 'Craig'),
        ('Howard', 'Stern'),
        ('Fred', 'Durst'),
        ('Arnold', 'Schwarzenegger'),
        ('Ashton', 'Kutcher'),
        ('Marshall', 'Mathers'),
        ('Dustin', 'Diamond'),
        ('Daniel', 'Radcliffe'),
        ('Danny', 'Bonaduce'),
        (u'Napoléon', 'Bonaparte'),
        )]


class ContactDatabase(Database):

    def __init__(self):
        create = not os.path.exists(CONTACT_DB)
        Database.__init__(self, CONTACT_DB)
        if create:
            cursor = self.db.cursor()
            cursor.execute(contact_db_sql)
            self.commit()
            for contact in initial_contacts:
                contact.save(self)
            self.commit()

    def fetch_contacts(self):
        return self.fetch_all(row_class=Contact,
                              order_args=(('lastname', ORDER_ASC),))
