from albatross.tags import escape
from albatross.ext.form import *
from db import ORDER_ASC
from contact import ContactDatabase


class DatabasePagedList(PagedListBase):

    def __init__(self, row_class, db_row_class,
                 order_args=None, pagesize=None):
        self.row_class = row_class
        self.db_row_class = db_row_class
        self.order_args = order_args
        self.items = None
        PagedListBase.__init__(self, pagesize)

    def connect(self):
        return ContactDatabase()

    def get_column_names(self):
        return [field.children[0].name for field in self.row_class().children]

    def items_on_page(self, page):
        db = self.connect()
        if self.pagesize:
            offset = (page - 1) * self.pagesize
            rows = db.fetch_all(row_class=self.db_row_class,
                                order_args=self.order_args,
                                offset=offset,
                                limit=self.pagesize)
        else:
            rows = db.fetch_all(row_class=self.db_row_class,
                                order_args=self.order_args)
        self.items = rows
        return [self.row_class(row) for row in self.items]

    def page_count(self):
        count, r = divmod(self.num_children(), self.pagesize)
        if r > 0:
            count += 1
        return count

    def get_child(self, index):
        return self.items[index]

    def num_children(self):
        db = self.connect()
        return db.count(self.db_row_class.table)

    def append(self, item):
        self.items.append(item)
        return self.row_class(item)

    def remove(self, item):
        pass

    def update(self, item):
        pass


class PageSelectionDisplay(PageSelectionDisplayBase):

    def write_link_for_page(self, ctx, form,
                            input_name, page, title, enabled=True):
        if enabled:
            data = '<a href="?%s=%s">%s</a>' % (input_name,
                                                page, escape(title))
        else:
            data = escape(title)
        form.write_content(ctx, data)

    def write_page_selection_above(self, ctx, form,
                                   input_name, paged_children, page):
        self.write_page_selection(ctx, form,
                                  input_name, paged_children, page)

    def write_page_selection_below(self, ctx, form,
                                   input_name, paged_children, page):
        pass

    def has_nextrange(self, page, size, page_count):
        return (page + size) < page_count

    def has_prevrange(self, page, size):
        return page > size

    def get_page_range(self, page, size, page_count):
        start = page / size * size + 1
        if start > page:
            start = start - size
        end = start + size - 1
        if end > page_count:
            end = page_count
        return range(start, end + 1)

    def write_page_selection(self, ctx, form,
                             input_name, paged_children, page):
        page_count = paged_children.page_count()
        if page_count < 2:
            return
        pagesize = paged_children.pagesize
        form.write_content(ctx, '<div class="pagination">')
        page_range = self.get_page_range(page, pagesize, page_count)
        if page > 1 and self.has_prevrange(page, pagesize):
            self.write_link_for_page(ctx, form, input_name, 1, '|<<')
        if self.has_prevrange(page, pagesize):
            self.write_link_for_page(ctx, form, input_name,
                                     page_range[0] - pagesize, '<<')
        for page_num in page_range:
            enabled = page_num != page
            self.write_link_for_page(ctx, form, input_name, page_num,
                                     str(page_num), enabled)
        if self.has_nextrange(page, pagesize, page_count):
            self.write_link_for_page(ctx, form, input_name,
                                     page_range[-1] + 1, '>>')
        if (page < page_count and
            self.has_nextrange(page, pagesize, page_count)):
            self.write_link_for_page(ctx, form, input_name, page_count, '>>|')
        form.write_content(ctx, '&nbsp;(%s/%s)</div>' % (page, page_count))
